@@ -50,9 +50,11 @@
 			if (x$typeof == 0){
 				tmp <- cbind(coef, exp(coef), seH, seHIH, coef/seH, signif(1 - 
 				pchisq((coef/seH)^2, 1), digits - 1))
+				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
 			}else{
 				tmp <- cbind(coef, exp(coef), seH, coef/seH, signif(1 - 
 				pchisq((coef/seH)^2, 1), digits - 1))
+				if(x$global_chisq.test==1) tmpwald <- cbind(x$global_chisq,x$dof_chisq,x$p.global_chisq)
 			}
 	
 			cat("\n")
@@ -65,21 +67,39 @@
 	
 			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")         
 			if (x$typeof == 0){
+				if(x$global_chisq.test==1){
+					dimnames(tmpwald) <- list(x$names.factor,c("chisq", "df", "global p"))
+					
+				}
 				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)", 
 				"SE coef (H)", "SE coef (HIH)", "z", "p"))
+
 			}else{
+				if(x$global_chisq.test==1){
+					dimnames(tmpwald) <- list(x$names.factor,c("chisq", "df", "global p"))
+					
+				}
 				dimnames(tmp) <- list(names(coef), c("coef", "exp(coef)", 
 				"SE coef (H)", "z", "p"))
+
 			}
 			cat("\n")
 			prmatrix(tmp)
+			if(x$global_chisq.test==1){
+				cat("\n")
+				prmatrix(tmpwald)
+			}
 			cat("\n")
 
 
-			if (x$correlation)cat("    Covariance (between the two frailty terms, \n
-			                the intercept and the slope):", x$cov, "(SE:",x$varcov^0.5, ")", "\n")
+			if (x$correlation){
+					cat("    Covariance (between the two frailty terms,  \n")
+					cat("        the intercept and the slope):", x$cov, "(SE:",x$varcov^0.5, ")", "\n")
+					cat("\n")
+			}
 		} 
-#AD:
+		
+#AD:		
 		if (x$noVar == 1){
 			cat("\n")
 			cat("    Additive gaussian frailty model: No covariates \n")
@@ -113,7 +133,7 @@
 			cat("    in the semi parametrical case     =",x$LCV,"\n")
 #AD:
 		}else{
-			cat(paste("    marginal log-likelihood =", round(x$logLikPenal,2)))
+			cat(paste("    marginal log-likelihood =", round(x$logLik,2)))
 			cat("\n")
 #			cat("      LCV = the approximate likelihood cross-validation criterion\n")
 #			cat("            in the parametrical case     =",x$LCV,"\n")	
@@ -132,7 +152,7 @@
 				}
 					cat("\n")
 					cat("The expression of the Weibull hazard function is:","\n")
-					cat("        'lambda(t) = shape(t^(shape-1)/(scale^shape)'","\n")
+					cat("        'lambda(t) = (shape.(t^(shape-1)))/(scale^shape)'","\n")
 					cat("The expression of the Weibull survival function is:","\n")
 					cat("        'S(t) = exp[- (t/scale)^shape]'")
 					cat("\n")
@@ -171,7 +191,7 @@
 					cat("       an approximated Cross validation: ", x$kappa[1])
 				} 
 			}
-		cat(", DoF: ", formatC(-x$DoF, format="f",dig=2))	
+		cat(", DoF: ", formatC(-x$DoF, format="f",digits=2))	
 		}
 	}else{
 		if (!is.null(coef)){ 	
